# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""


import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from grid.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from grid.openapi.models import *

class V1ExperimentEvent(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'desired_state': 'V1ExperimentState',
        'id': 'str',
        'message': 'str',
        'phase': 'V1ExperimentState',
        'timestamp': 'datetime'
    }

    attribute_map = {
        'desired_state': 'desiredState',
        'id': 'id',
        'message': 'message',
        'phase': 'phase',
        'timestamp': 'timestamp'
    }

    def __init__(self, desired_state: 'V1ExperimentState' = None, id: 'str' = None, message: 'str' = None, phase: 'V1ExperimentState' = None, timestamp: 'datetime' = None, _configuration=None):  # noqa: E501
        """V1ExperimentEvent - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._desired_state = None
        self._id = None
        self._message = None
        self._phase = None
        self._timestamp = None
        self.discriminator = None

        if desired_state is not None:
            self.desired_state = desired_state
        if id is not None:
            self.id = id
        if message is not None:
            self.message = message
        if phase is not None:
            self.phase = phase
        if timestamp is not None:
            self.timestamp = timestamp

    @property
    def desired_state(self) -> 'V1ExperimentState':
        """Gets the desired_state of this V1ExperimentEvent.  # noqa: E501


        :return: The desired_state of this V1ExperimentEvent.  # noqa: E501
        :rtype: V1ExperimentState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state: 'V1ExperimentState'):
        """Sets the desired_state of this V1ExperimentEvent.


        :param desired_state: The desired_state of this V1ExperimentEvent.  # noqa: E501
        :type: V1ExperimentState
        """

        self._desired_state = desired_state

    @property
    def id(self) -> 'str':
        """Gets the id of this V1ExperimentEvent.  # noqa: E501


        :return: The id of this V1ExperimentEvent.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1ExperimentEvent.


        :param id: The id of this V1ExperimentEvent.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def message(self) -> 'str':
        """Gets the message of this V1ExperimentEvent.  # noqa: E501


        :return: The message of this V1ExperimentEvent.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message: 'str'):
        """Sets the message of this V1ExperimentEvent.


        :param message: The message of this V1ExperimentEvent.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def phase(self) -> 'V1ExperimentState':
        """Gets the phase of this V1ExperimentEvent.  # noqa: E501


        :return: The phase of this V1ExperimentEvent.  # noqa: E501
        :rtype: V1ExperimentState
        """
        return self._phase

    @phase.setter
    def phase(self, phase: 'V1ExperimentState'):
        """Sets the phase of this V1ExperimentEvent.


        :param phase: The phase of this V1ExperimentEvent.  # noqa: E501
        :type: V1ExperimentState
        """

        self._phase = phase

    @property
    def timestamp(self) -> 'datetime':
        """Gets the timestamp of this V1ExperimentEvent.  # noqa: E501


        :return: The timestamp of this V1ExperimentEvent.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp: 'datetime'):
        """Sets the timestamp of this V1ExperimentEvent.


        :param timestamp: The timestamp of this V1ExperimentEvent.  # noqa: E501
        :type: datetime
        """

        self._timestamp = timestamp

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1ExperimentEvent, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1ExperimentEvent') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ExperimentEvent):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1ExperimentEvent') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1ExperimentEvent):
            return True

        return self.to_dict() != other.to_dict()
